=======
History
=======


v0.1.1 (2018-10-08)

===================

* New google compute helpers (see rhg_compute_tools.gcs.cp_to_gcs, rhg_compute_tools.gcs.get_bucket)
* New cluster creation helper (see rhg_compute_tools.kubernetes.get_worker)
* Dask client.map helpers (see rhg_compute_tools.utils submodule)



v0.1.0 (2018-08-07)
===================

* First release on PyPI.
